# PSHA Dev
Workflows and library code for _Probabilistic Seismic Hazard Analysis_ (PSHA).
The workflows are intended for the DT-GEO project.

## Overview
This repository is mainly divided into library code, located in the `psha` folder, and workflows.
Workflows are given as Python scripts, that read input files, perform some computation, and produce output files.
``` text
├── psha
│   ├── common
│   ├── completeness
│   ├── harmonize
│   ├── mfd
|   └── HOWTO.ipynb
└── workflows_a
    ├── A00
    ├── A01
    └── A2

```
For the psha lib, please check out the [how to notebook](./psha/HOWTO.ipynb).


For the workflows, please check out the `README` files in their folders.
As a general note, the original workflows, prefixed with `eshm20_`, are included for reference as well (they are not in a runnable state).


## Development setup
Requires Python >= 3.10

``` bash
# create a virtual environment
python3 -m venv env

# activate the virtual environment
source env/bin/activate

# update build tools
pip install -U pip wheel setuptools

# install this package with dev requirements
pip install -e '.[dev]'

# Run tests
pytest

# Lint
flake8
```


## Related
- [py_dev_src_v14](https://gitlab.seismo.ethz.ch/danciul/py_dev_src_v14/-/tree/master?ref_type=heads)
- [SeismoStats](https://github.com/swiss-seismological-service/SeismoStats)