import os
from pathlib import Path

import pandas as pd

from psha.completeness.completeness_filter import completeness_filter

DATA = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                    'data')


def test_completeness_filter(tmp_path: Path,):
    catalog_path = os.path.join(DATA, "sampled_EMEC_test.csv")
    completeness_file = os.path.join(
        DATA, "McTable_CSZ_branch01_modified_default_dec2020.csv")
    csz_shapefile = os.path.join(DATA, "eshm20_csz_v06b.shp")

    output_path = tmp_path / "sampled_EMEC_test_filtered.csv"
    completeness_filter(catalog_path, completeness_file,
                        csz_shapefile, output_path)
    df_got = pd.read_csv(output_path)
    expected_path = os.path.join(DATA, "sampled_EMEC_test_filtered.csv")
    df_expected = pd.read_csv(expected_path)
    not_removed = set(df_got["eventID"].to_list())
    expected_not_removed = set(df_expected["eventID"].to_list())
    assert not_removed == expected_not_removed


def test_completeness_filter_small():
    catalog_path = os.path.join(DATA, "catalog_small.csv")
    completeness_file = os.path.join(
        DATA, "McTable_small.csv")
    csz_shapefile = os.path.join(DATA, "eshm20_csz_v06b.shp")

    catalog = pd.read_csv(catalog_path)
    expected = catalog["removed"].astype(bool)
    ids = catalog["eventID"]
    df_out = completeness_filter(catalog_path, completeness_file,
                                 csz_shapefile)

    kept = set(df_out["eventID"].to_list())
    for exp, i in zip(expected, ids):
        got = i not in kept
        assert exp == got
