# Workflow A01: Declustering

This workflow applies _declustering_ to the input catalog.
A boolean column is added, indicating whether an event is a mainshock or not.

## Parameters
- input_catalog_path
    - csv format
    - required columns are `time, magnitude, longitude, latitude`
- output_column_name
    - names the column for the result
- output_catalog_path
    - csv format
    - same as input, with column output_column_name added
- declusterer
    - [SeismoStats declusterers](https://github.com/swiss-seismological-service/SeismoStats/tree/main/seismostats/analysis/declustering) can be used
    - so far only `GardnerKnopoffType1` with the time distance window `GardnerKnopoffWindow` or `GruenthalWindow`.

## Configuring and running
We can configure the workflow with the file `A01_config.toml`:
``` toml
input_catalog_path = "tests/data/test_eshm20_deep60km_decl.csv"
output_column_name = "mainshock_flag"
output_catalog_path = "output/test_eshm20_deep60km_decl.csv"
verbose = 1
# string of the declusterer class name
declusterer = "GardnerKnopoffType1"  
[declusterer_args]
# The arguments passed to the declustering class
# or "GruenthalWindow"
# string of the window class name
time_distance_window = "GardnerKnopoffWindow" 
fs_time_prop = 0.17
```

Let's run it
``` bash
cd workflows_a/A01/
python workflow_A01_declustering.py 
```

Then the file `output/test_eshm20_deep60km_decl.csv` is produced,
with the new column `mainshock_flag`:
``` text
time,longitude,latitude,magnitude,depth,eventID,winGT_fs0.17,winGK_fs0.17,mainshock_flag
1107-02-12 03:00:00,26.6,45.7,7.1,150.0,10000047,True,True,True
1122-10-01 00:00:00,26.6,45.7,6.2,150.0,10000055,True,True,True
1126-08-08 00:00:00,26.6,45.7,7.1,150.0,10000058,True,True,True
1196-02-13 07:00:00,26.6,45.7,7.5,150.0,10000092,True,True,True
...
```

## Tests
There are regression tests for two catalogues, declustering with `GardnerKnopoffType1` for each of the two time distance windows.


## Notes
TODO previous declusterers e.g. Reasenberg (buggy), Zaliapin
TODO openquake issues