import os
from pathlib import Path

import pandas as pd
import pytest
from seismostats.analysis.declustering import GardnerKnopoffType1
from seismostats.analysis.declustering.distance_time_windows import (
    GardnerKnopoffWindow, GruenthalWindow)

from workflows_a.A01.workflow_A01_declustering import decluster_mainshocks

GKGT = {
    "declusterer": GardnerKnopoffType1(
        time_distance_window=GruenthalWindow(),
        fs_time_prop=0.17
    ),
    "output_column_name": "winGT_mainshock",
    "verbose": True
}
GKGK = {
    "declusterer": GardnerKnopoffType1(
        fs_time_prop=0.17,
        time_distance_window=GardnerKnopoffWindow()
    ),
    "output_column_name": "winGK_mainshock",
    "verbose": True
}

BASE_DATA_PATH = Path(os.path.dirname(__file__)) / "data"


@pytest.mark.parametrize("config, expected, exptected_col",
                         [(GKGT,
                           "test_fdsnws2020_decl.csv",
                           "winGT_fs0.17"),
                          (GKGK,
                           "test_fdsnws2020_decl.csv",
                           "winGK_fs0.17"),
                          (GKGT,
                           "test_eshm20_deep60km_decl.csv",
                           "winGT_fs0.17"),
                          (GKGK,
                           "test_eshm20_deep60km_decl.csv",
                           "winGK_fs0.17"),
                          ])
def test_mainshock_regression(tmp_path: Path, config, expected, exptected_col):
    output_path = tmp_path / "decluster_test.csv"
    expected_output = BASE_DATA_PATH / expected
    df_expected = pd.read_csv(expected_output)
    want = df_expected[exptected_col]
    col = config["output_column_name"]
    df_in = df_expected.copy()
    if col in df_expected.columns:
        df_in.drop(columns=col, inplace=True)
    input_path = tmp_path / "input_decluster_test.csv"
    df_in.to_csv(input_path, index=False)

    decluster_mainshocks(input_path, output_path=output_path, **config)

    results = pd.read_csv(output_path)
    got = results[col]
    diff = got != want
    print(f"Found {diff.sum()} inconsistencies for {col} out of {len(got)}")
    assert want.equals(got)
