#!/bin/bash

# scripts checks if we still output the same XML files
# DIR1 contains the reference regression files
# which are compared against the output in DIR2
#
# NOTE: the regression folder contains files for both
# the Static (no (magnitude_threshold) and fMthrVar (magnitude_threshold = 5.9) versions.


# Directories to compare
DIR1="test/data/regression/out_nrmls/"
DIR2="output/nrmls/"

# Check if both directories exist
if [[ ! -d "$DIR1" || ! -d "$DIR2" ]]; then
  echo "Error: One or both directories do not exist."
  exit 1
fi

# Flag to track success
success=0

# Loop through files in DIR1
for file1 in "$DIR1"/*; do
  filename=$(basename "$file1") # Extract filename
  file2="$DIR2/$filename"       # Corresponding file in DIR2

  if [[ -f "$file2" ]]; then
    if ! diff -q "$file1" "$file2" >/dev/null; then
      echo "Differences found in $filename."
      success=1
    fi
  else
    echo "File $filename exists in $DIR1 but not in $DIR2."
    success=1
  fi
done

# Check for files in DIR2 that are missing in DIR1
for file2 in "$DIR2"/*; do
  filename=$(basename "$file2") # Extract filename
  file1="$DIR1/$filename"       # Corresponding file in DIR1

  if [[ ! -f "$file1" ]]; then
    echo "File $filename exists in $DIR2 but not in $DIR1."
    success=1
  fi
done

exit $success
